// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef DOLPHINVCS_VERSION_H
#define DOLPHINVCS_VERSION_H

#define DOLPHINVCS_VERSION_STRING "26.08.0"
#define DOLPHINVCS_VERSION_MAJOR 26
#define DOLPHINVCS_VERSION_MINOR 8
#define DOLPHINVCS_VERSION_PATCH 0
#define DOLPHINVCS_VERSION ((26<<16)|(8<<8)|(0))

#endif
